@@ -27,14 +27,9 @@
 #ifndef _palmstd_h
 #define _palmstd_h
 
-void *memptrnew (ULONG size);
-UCHAR memptrfree (void *p);
-
 UCHAR FileDump (UCHAR *mem,UCHAR *file,USHORT start,USHORT len);
 UCHAR FileCreate (UCHAR *file,ULONG size);
-UCHAR filewrite (UCHAR *file,UCHAR *mem,ULONG start,ULONG length);
+UCHAR filewrite (UCHAR *file,UCHAR *mem,ULONG start,ULONG length, int resize);
+int filesize(UCHAR *file);
 struct rgb *getrgb (UCHAR color);
-UCHAR *FileMemAlloc (UCHAR *file,ULONG len,DmOpenRef *ref,MemHandle *m);
-void FileMemRelease (UCHAR *file,DmOpenRef *ref,MemHandle *m);
-
 #endif  // _palmstd_h
